JourneyStep class

Constructors

JourneyStep({required Future<void> prepare(PatrolTester $), required Future<void> walk(PatrolTester $)})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
prepare Future<void> Function(PatrolTester $)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
walk Future<void> Function(PatrolTester $)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited