LazyVerification class

Constructors

LazyVerification(Verification _verification())
const

Properties

calledOnce → void
no setteroverride
count int
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
never → void
no setteroverride
requests List<MockHttpRequest>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
single → MockHttpRequest
no setteroverride

Methods

called(int times) → void
override
calledAtLeast(int times) → void
override
calledAtMost(int times) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited